==> modified-shop_1.06-r4642_install.zip: modified-shop_1.06-r4642_install/shoproot/lang/german/admin/cross_sell_groups.php <==
<?php
/* --------------------------------------------------------------
   $Id: cross_sell_groups.php 1231 2005-09-21 13:05:36Z mz $   

   XT-Commerce - community made shopping
   http://www.xt-commerce.com

   Copyright (c) 2003 XT-Commerce
   --------------------------------------------------------------
   based on: 
   (c) 2000-2001 The Exchange Project  (earlier name of osCommerce)
   (c) 2002-2003 osCommerce(orders_status.php,v 1.7 2002/01/30); www.oscommerce.com 
   (c) 2003	 nextcommerce (orders_status.php,v 1.4 2003/08/14); www.nextcommerce.org

   Released under the GNU General Public License 
   --------------------------------------------------------------*/

define('HEADING_TITLE', 'Cross-Marketing Gruppen');

define('TABLE_HEADING_XSELL_GROUP_NAME', 'Gruppenname');
define('TABLE_HEADING_ACTION', 'Aktion');

define('TEXT_INFO_EDIT_INTRO', 'Bitte f&uuml;hren Sie alle notwendigen &Auml;nderungen durch');
define('TEXT_INFO_XSELL_GROUP_NAME', 'Gruppenname:');
define('TEXT_INFO_INSERT_INTRO', 'Bitte geben Sie den neuen Gruppennamen mit allen relevanten Daten ein');
define('TEXT_INFO_DELETE_INTRO', 'Sind Sie sicher, dass Sie diese Gruppe l&ouml;schen m&ouml;chten?');
define('TEXT_INFO_HEADING_NEW_XSELL_GROUP', 'Neuer Gruppenname');
define('TEXT_INFO_HEADING_EDIT_XSELL_GROUP', 'Gruppenname bearbeiten');
define('TEXT_INFO_HEADING_DELETE_XSELL_GROUP', 'Gruppenname l&ouml;schen');
define('ERROR_STATUS_USED_IN_ORDERS', 'Fehler: Diese Gruppe wird zur Zeit noch bei Cross-Marketing Artikeln verwendet.');

?>

==> modified-shop_2.0.7.2-r14622_install.zip: modified-shop_2.0.7.2-r14622_install/shoproot/lang/german/admin/cross_sell_groups.php <==
<?php
/* --------------------------------------------------------------
   $Id: cross_sell_groups.php 13119 2021-01-05 17:38:59Z GTB $   

   XT-Commerce - community made shopping
   http://www.xt-commerce.com

   Copyright (c) 2003 XT-Commerce
   --------------------------------------------------------------
   based on: 
   (c) 2000-2001 The Exchange Project  (earlier name of osCommerce)
   (c) 2002-2003 osCommerce(orders_status.php,v 1.7 2002/01/30); www.oscommerce.com 
   (c) 2003	 nextcommerce (orders_status.php,v 1.4 2003/08/14); www.nextcommerce.org

   Released under the GNU General Public License 
   --------------------------------------------------------------*/

define('HEADING_TITLE', 'Cross-Marketing Gruppen');

define('TABLE_HEADING_XSELL_GROUP_ID', 'ID');
define('TABLE_HEADING_XSELL_GROUP_NAME', 'Gruppenname');
define('TABLE_HEADING_XSELL_GROUP_SORT_ORDER', 'Sortierung');
define('TABLE_HEADING_ACTION', 'Aktion');

define('TEXT_INFO_EDIT_INTRO', 'Bitte f&uuml;hren Sie alle notwendigen &Auml;nderungen durch');
define('TEXT_INFO_XSELL_GROUP_NAME', 'Gruppenname:');
define('TEXT_INFO_XSELL_GROUP_SORT_ORDER', 'Sortierung:');
define('TEXT_INFO_INSERT_INTRO', 'Bitte geben Sie den neuen Gruppennamen mit allen relevanten Daten ein');
define('TEXT_INFO_DELETE_INTRO', 'Sind Sie sicher, dass Sie diese Gruppe l&ouml;schen m&ouml;chten?');
define('TEXT_INFO_HEADING_NEW_XSELL_GROUP', 'Neuer Gruppenname');
define('TEXT_INFO_HEADING_EDIT_XSELL_GROUP', 'Gruppenname bearbeiten');
define('TEXT_INFO_HEADING_DELETE_XSELL_GROUP', 'Gruppenname l&ouml;schen');
define('ERROR_STATUS_USED_IN_CROSS_SELLS', 'Fehler: Diese Gruppe wird zur Zeit noch bei Cross-Marketing Artikeln verwendet.');
?>
